@@ -25,7 +25,7 @@ from octaviaclient.osc.v2 import constants as const
 from octaviaclient.osc.v2 import utils as v2_utils
 from octaviaclient.osc.v2 import validate
 
-PROTOCOL_CHOICES = ['TCP', 'HTTP', 'HTTPS', 'TERMINATED_HTTPS', 'UDP']
+PROTOCOL_CHOICES = ['TCP', 'HTTP', 'HTTPS', 'TERMINATED_HTTPS', 'UDP', 'SCTP']
 CLIENT_AUTH_CHOICES = ['NONE', 'OPTIONAL', 'MANDATORY']
 
 
@@ -33,7 +33,7 @@ class CreateListener(command.ShowOne):
     """Create a listener"""
 
     def get_parser(self, prog_name):
-        parser = super(CreateListener, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
 
         parser.add_argument(
             'loadbalancer',
@@ -190,6 +190,15 @@ class CreateListener(command.ShowOne):
             help="Set the TLS protocol version to be used "
                  "by the listener (can be set multiple times)."
         )
+        parser.add_argument(
+            '--alpn-protocol',
+            dest='alpn_protocols',
+            metavar='<alpn_protocols>',
+            nargs='?',
+            action='append',
+            help="Set the ALPN protocol to be used "
+                 "by the listener (can be set multiple times)."
+        )
 
         return parser
 
@@ -232,7 +241,7 @@ class DeleteListener(command.Command):
     """Delete a listener"""
 
     def get_parser(self, prog_name):
-        parser = super(DeleteListener, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
 
         parser.add_argument(
             'listener',
@@ -267,7 +276,7 @@ class ListListener(lister.Lister):
     """List listeners"""
 
     def get_parser(self, prog_name):
-        parser = super(ListListener, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
 
         parser.add_argument(
             '--name',
@@ -316,7 +325,7 @@ class ShowListener(command.ShowOne):
     """Show the details of a single listener"""
 
     def get_parser(self, prog_name):
-        parser = super(ShowListener, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
 
         parser.add_argument(
             'listener',
@@ -358,7 +367,7 @@ class SetListener(command.Command):
     """Update a listener"""
 
     def get_parser(self, prog_name):
-        parser = super(SetListener, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
 
         parser.add_argument(
             'listener',
@@ -500,6 +509,15 @@ class SetListener(command.Command):
             help="Set the TLS protocol version to be used "
                  "by the listener (can be set multiple times)."
         )
+        parser.add_argument(
+            '--alpn-protocol',
+            dest='alpn_protocols',
+            metavar='<alpn_protocols>',
+            nargs='?',
+            action='append',
+            help="Set the ALPN protocol to be used "
+                 "by the listener (can be set multiple times)."
+        )
 
         return parser
 
@@ -525,7 +543,7 @@ class UnsetListener(command.Command):
     """Clear listener settings"""
 
     def get_parser(self, prog_name):
-        parser = super(UnsetListener, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
 
         parser.add_argument(
             'listener',
@@ -610,10 +628,25 @@ class UnsetListener(command.Command):
             action='store_true',
             help="Clear all allowed CIDRs from the listener."
         )
+        parser.add_argument(
+            '--tls-versions',
+            action='store_true',
+            help='Clear all TLS versions from the listener.',
+        )
+        parser.add_argument(
+            '--tls-ciphers',
+            action='store_true',
+            help='Clear all TLS ciphers from the listener.',
+        )
         parser.add_argument(
             '--wait',
             action='store_true',
-            help='Wait for action to complete',
+            help='Wait for action to complete.',
+        )
+        parser.add_argument(
+            '--alpn-protocols',
+            action='store_true',
+            help="Clear all ALPN protocols from the listener."
         )
         return parser
 
@@ -642,7 +675,7 @@ class ShowListenerStats(command.ShowOne):
     """Shows the current statistics for a listener."""
 
     def get_parser(self, prog_name):
-        parser = super(ShowListenerStats, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
 
         parser.add_argument(
             'listener',
